
"""
Mintalib Functions

Function names are upper case.

Functions that accept a prices dataframe input have a first paramater called `prices`.
Functions that accept a series input have a fist parameter called `series`,
and an optional parameter `item` to specify which column to use on dataframe inputs.

All functions wrap their output to match the type of their input.
In particular the result of a function applied to a pandas series or dataframes
will have the same index as the input. 
"""

# Do not edit! This file was generated by make-functions.ipynb

from .core import (
    AVGPRICE, TYPPRICE, WCLPRICE, MIDPRICE, PRICE, CROSSOVER, CROSSUNDER,
    FLAG, UPDOWN, SIGN, LOG, EXP, DIFF, LAG, MIN, MAX, SUM, ROC, MAD,
    STDEV, SMA, EMA, RMA, WMA, HMA, DEMA, TEMA, MA, RSI, DMI, ADX, PDI,
    MDI, TRANGE, ATR, NATR, SAR, CCI, CMF, MFI, BOP, BBANDS, KELTNER, KER,
    KAMA, MACD, PPO, SLOPE, RVALUE, FORECAST, CURVE, STOCH, STREAK, EVAL
)

__all__ = [
    'AVGPRICE', 'TYPPRICE', 'WCLPRICE', 'MIDPRICE', 'PRICE', 'CROSSOVER',
    'CROSSUNDER', 'FLAG', 'UPDOWN', 'SIGN', 'LOG', 'EXP', 'DIFF', 'LAG',
    'MIN', 'MAX', 'SUM', 'ROC', 'MAD', 'STDEV', 'SMA', 'EMA', 'RMA', 'WMA',
    'HMA', 'DEMA', 'TEMA', 'MA', 'RSI', 'DMI', 'ADX', 'PDI', 'MDI',
    'TRANGE', 'ATR', 'NATR', 'SAR', 'CCI', 'CMF', 'MFI', 'BOP', 'BBANDS',
    'KELTNER', 'KER', 'KAMA', 'MACD', 'PPO', 'SLOPE', 'RVALUE', 'FORECAST',
    'CURVE', 'STOCH', 'STREAK', 'EVAL'
]
